@@ -13,7 +13,6 @@ Usage::
 """
 from typing import Any, Dict, Type
 
-from boto3.botocore_stubs import ClientError as BotocoreClientError
 from botocore.client import ClientMeta
 
 from mypy_boto3_forecastquery.type_defs import QueryForecastResponseTypeDef
@@ -21,6 +20,14 @@ from mypy_boto3_forecastquery.type_defs import QueryForecastResponseTypeDef
 __all__ = ("ForecastQueryServiceClient",)
 
 
+class BotocoreClientError(BaseException):
+    MSG_TEMPLATE: str
+
+    def __init__(self, error_response: Dict[str, Any], operation_name: str) -> None:
+        self.response: Dict[str, Any]
+        self.operation_name: str
+
+
 class Exceptions:
     ClientError: Type[BotocoreClientError]
     InvalidInputException: Type[BotocoreClientError]
